@@ -55,6 +55,9 @@ public interface HostsService extends Service {
      * NOTE: The `root_password` element is only included in the client-provided initial representation and is not
      * exposed in the representations returned from subsequent requests.
      * 
+     * IMPORTANT: Since version 4.1.2 of the engine when a host is newly added we override the host firewall
+     * definitions by default.
+     * 
      * To add a hosted engine host, use the optional `deploy_hosted_engine` parameter:
      * 
      * [source]
@@ -110,6 +113,9 @@ public interface HostsService extends Service {
      * NOTE: The `root_password` element is only included in the client-provided initial representation and is not
      * exposed in the representations returned from subsequent requests.
      * 
+     * IMPORTANT: Since version 4.1.2 of the engine when a host is newly added we override the host firewall
+     * definitions by default.
+     * 
      * To add a hosted engine host, use the optional `deploy_hosted_engine` parameter:
      * 
      * [source]
@@ -152,6 +158,9 @@ public interface HostsService extends Service {
      * NOTE: The `root_password` element is only included in the client-provided initial representation and is not
      * exposed in the representations returned from subsequent requests.
      * 
+     * IMPORTANT: Since version 4.1.2 of the engine when a host is newly added we override the host firewall
+     * definitions by default.
+     * 
      * To add a hosted engine host, use the optional `deploy_hosted_engine` parameter:
      * 
      * [source]
@@ -184,8 +193,29 @@ public interface HostsService extends Service {
      *   ...
      * </host>
      * ----
+     * 
+     * The order of the returned list of hosts is guaranteed only if the `sortby` clause is included in
+     * the `search` parameter.
      */
     public interface ListRequest extends Request<ListRequest, ListResponse> {
+        /**
+         * Indicates if all of the attributes of the hosts should be included in the response.
+         * 
+         * By default the following host attributes are excluded:
+         * 
+         * - `hosted_engine`
+         * 
+         * For example, to retrieve the complete representation of the hosts:
+         * 
+         * ....
+         * GET /ovirt-engine/api/hosts?all_content=true
+         * ....
+         * 
+         * NOTE: These attributes are not included by default because retrieving them impacts performance. They are
+         * seldom used and require additional queries to the database. Use this parameter with caution and only when
+         * specifically required.
+         */
+        ListRequest allContent(Boolean allContent);
         /**
          * Indicates if the search performed using the `search` parameter should be performed taking case into
          * account. The default value is `true`, which means that case is taken into account. If you want to search
@@ -237,6 +267,9 @@ public interface HostsService extends Service {
      *   ...
      * </host>
      * ----
+     * 
+     * The order of the returned list of hosts is guaranteed only if the `sortby` clause is included in
+     * the `search` parameter.
      */
     public interface ListResponse extends Response {
         List<Host> hosts();
@@ -265,6 +298,9 @@ public interface HostsService extends Service {
      *   ...
      * </host>
      * ----
+     * 
+     * The order of the returned list of hosts is guaranteed only if the `sortby` clause is included in
+     * the `search` parameter.
      */
     ListRequest list();
     
