@@ -66,6 +66,7 @@ import org.ovirt.engine.sdk4.types.SnapshotType;
 import org.ovirt.engine.sdk4.types.Sso;
 import org.ovirt.engine.sdk4.types.Statistic;
 import org.ovirt.engine.sdk4.types.StorageDomain;
+import org.ovirt.engine.sdk4.types.StorageDomainLease;
 import org.ovirt.engine.sdk4.types.Tag;
 import org.ovirt.engine.sdk4.types.Template;
 import org.ovirt.engine.sdk4.types.TimeZone;
@@ -117,6 +118,7 @@ public class SnapshotBuilder {
     private Io io;
     private List<KatelloErratum> katelloErrata;
     private Icon largeIcon;
+    private StorageDomainLease lease;
     private BigInteger memory;
     private MemoryPolicy memoryPolicy;
     private MigrationOptions migration;
@@ -127,6 +129,7 @@ public class SnapshotBuilder {
     private List<NumaNode> numaNodes;
     private NumaTuneMode numaTuneMode;
     private String origin;
+    private Template originalTemplate;
     private OperatingSystem os;
     private List<Payload> payloads;
     private List<Permission> permissions;
@@ -863,6 +866,22 @@ public class SnapshotBuilder {
     }
     
     
+    public SnapshotBuilder lease(StorageDomainLease newLease) {
+        lease = newLease;
+        return this;
+    }
+    
+    public SnapshotBuilder lease(StorageDomainLeaseBuilder newLease) {
+        if (newLease == null) {
+            lease = null;
+        }
+        else {
+            lease = newLease.build();
+        }
+        return this;
+    }
+    
+    
     public SnapshotBuilder memory(int newMemory) {
         memory = BigInteger.valueOf((long) newMemory);
         return this;
@@ -1066,6 +1085,22 @@ public class SnapshotBuilder {
     }
     
     
+    public SnapshotBuilder originalTemplate(Template newOriginalTemplate) {
+        originalTemplate = newOriginalTemplate;
+        return this;
+    }
+    
+    public SnapshotBuilder originalTemplate(TemplateBuilder newOriginalTemplate) {
+        if (newOriginalTemplate == null) {
+            originalTemplate = null;
+        }
+        else {
+            originalTemplate = newOriginalTemplate.build();
+        }
+        return this;
+    }
+    
+    
     public SnapshotBuilder os(OperatingSystem newOs) {
         os = newOs;
         return this;
@@ -1744,6 +1779,7 @@ public class SnapshotBuilder {
         container.io(io);
         container.katelloErrata(katelloErrata);
         container.largeIcon(largeIcon);
+        container.lease(lease);
         container.memory(memory);
         container.memoryPolicy(memoryPolicy);
         container.migration(migration);
@@ -1754,6 +1790,7 @@ public class SnapshotBuilder {
         container.numaNodes(numaNodes);
         container.numaTuneMode(numaTuneMode);
         container.origin(origin);
+        container.originalTemplate(originalTemplate);
         container.os(os);
         container.payloads(payloads);
         container.permissions(permissions);
