@@ -23,6 +23,10 @@ public interface HostDevice extends Identified {
     
     boolean capabilityPresent();
     
+    String driver();
+    
+    boolean driverPresent();
+    
     BigInteger iommuGroup();
     
     boolean iommuGroupPresent();
